pub struct AgentRunner { /* private fields */ }Expand description
A sub-agent runner.
This runs autonomous agents that do not require user input. Agents are run until “complete_task” is called. This currently has some duplicated logic with chat/ai.rs & chat/tools.rs. We need to refactor to better abstract out execution. This currently exists separately from ChatActor for background tasks like memory management.
Implementations
Sourceimpl AgentRunner
impl AgentRunner
pub fn new( ai_provider: Arc<dyn AiProvider>, settings: SettingsManager, tools: BTreeMap<String, Arc<dyn ToolExecutor + Send + Sync>>, modules: Vec<Arc<dyn Module>>, steering: SteeringDocuments, prompt_builder: PromptBuilder, context_builder: ContextBuilder, ) -> Self