pub enum MockBehavior {
Success,
RetryableErrorThenSuccess {
remaining_errors: usize,
},
AlwaysRetryableError,
AlwaysNonRetryableError,
ToolUse {
tool_name: String,
tool_arguments: String,
},
ToolUseThenSuccess {
tool_name: String,
tool_arguments: String,
},
AlwaysInputTooLong,
InputTooLongThenSuccess {
remaining_errors: usize,
},
TextOnlyThenToolUse {
remaining_text_responses: usize,
tool_name: String,
tool_arguments: String,
},
ToolUseThenToolUse {
first_tool_name: String,
first_tool_arguments: String,
second_tool_name: String,
second_tool_arguments: String,
},
MultipleToolUses {
tool_uses: Vec<(String, String)>,
},
BehaviorQueue {
behaviors: Vec<MockBehavior>,
},
}Expand description
Mock behavior for the mock provider
Variants
Success
Return successful responses
RetryableErrorThenSuccess
Return a retryable error N times, then succeed
AlwaysRetryableError
Always return a retryable error
AlwaysNonRetryableError
Always return a non-retryable error
ToolUse
Return a tool use response
ToolUseThenSuccess
Return a tool use response once, then success
AlwaysInputTooLong
Always return an InputTooLong error
InputTooLongThenSuccess
Return InputTooLong error N times, then succeed
TextOnlyThenToolUse
Return text-only responses N times, then a tool use response
ToolUseThenToolUse
Return two tool uses in sequence, then success
Fields
MultipleToolUses
Return multiple tool uses in a single response, then success
BehaviorQueue
Enables sequential multi-turn conversation testing by orchestrating predetermined agent responses
Fields

behaviors: Vec<MockBehavior>Trait Implementations
Sourceimpl Clone for MockBehavior
impl Clone for MockBehavior
Sourcefn clone(&self) -> MockBehavior
fn clone(&self) -> MockBehavior
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MockBehavior
impl Debug for MockBehavior
Sourceimpl Default for MockBehavior
impl Default for MockBehavior
Sourcefn default() -> MockBehavior
fn default() -> MockBehavior
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for MockBehavior
impl<'de> Deserialize<'de> for MockBehavior
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more