pub enum Model {
Show 17 variants
ClaudeOpus46,
ClaudeOpus45,
ClaudeSonnet45,
ClaudeHaiku45,
Gemini3ProPreview,
Gpt52,
Gpt51CodexMax,
KimiK25,
Gemini3FlashPreview,
GLM47,
MinimaxM21,
Grok41Fast,
GrokCodeFast1,
Qwen3Coder,
GptOss120b,
OpenRouterAuto,
None,
}Expand description
The supported models, subjectively ranked by quality
Variants
ClaudeOpus46
ClaudeOpus45
ClaudeSonnet45
ClaudeHaiku45
Gemini3ProPreview
Gpt52
Gpt51CodexMax
KimiK25
Gemini3FlashPreview
GLM47
MinimaxM21
Grok41Fast
GrokCodeFast1
Qwen3Coder
GptOss120b
OpenRouterAuto
None
This allows code to match all models, but still match _ => to avoid being required to match all models.
Implementations
Sourceimpl Model
impl Model
pub fn tweaks(self) -> ModelTweaks
pub const fn name(self) -> &'static str
pub fn from_name(s: &str) -> Option<Self>
pub const fn supports_prompt_caching(self) -> bool
pub fn default_settings(self) -> ModelSettings
Sourcepub fn select_for_cost(
provider: &dyn AiProvider,
quality: ModelCost,
) -> Option<ModelSettings>
pub fn select_for_cost( provider: &dyn AiProvider, quality: ModelCost, ) -> Option<ModelSettings>
Select the highest quality model supported by the provider that fits the cost threshold. For Unlimited, returns the highest supported model. For others, filters by max(input/output cost per million tokens) <= threshold. Free requires exact 0.0 match. Ranked highest-to-lowest to prefer premium within budget. Returns None if no fit (surfaces error to caller—no fallback).