ChatActorMessage

Enum ChatActorMessage 

pub enum ChatActorMessage {
    UserInput(String),
    UserInputWithImages {
        text: String,
        images: Vec<ImageData>,
    },
    ChangeProvider(String),
    GetSettings,
    SaveSettings {
        settings: Value,
        persist: bool,
    },
    SwitchProfile {
        profile_name: String,
    },
    SaveProfile {
        profile_name: String,
    },
    ListProfiles,
    ListSessions,
    ResumeSession {
        session_id: String,
    },
    GetModuleSchemas,
}
Defines the possible input messages to the ChatActor.

These messages derive serde for use across processes. Applications such as VSCode spawn tycode-core in a sub-process and communicate to the actor over stdin/stdout. In such applications, these messages are serialized to json and sent over stdin.

Variants



UserInput(String)

A user input to the conversation with the current AI agent



UserInputWithImages

A user input with attached images

Fields

text: String
images: Vec<ImageData>


ChangeProvider(String)

Changes the AI provider (i.e. Bedrock, OpenRouter, etc) that this actor is using. This is an in-memory only change that only lasts for the duration of this actor’s lifetime.



GetSettings

Sends the current settings (from SettingsManager) to the EventSender



SaveSettings

Fields

settings: Value
persist: bool


SwitchProfile

Switches to a different settings profile

Fields

profile_name: String


SaveProfile

Saves current settings as a new profile

Fields

profile_name: String


ListProfiles

Lists all available settings profiles



ListSessions

Requests all available sessions



ResumeSession

Requests to resume a specific session

Fields

session_id: String


GetModuleSchemas

Requests JSON schemas for all module settings