pub async fn create_provider(
settings: &SettingsManager,
provider: &str,
) -> Result<Arc<dyn AiProvider>>Expand description
Initializes the provider with the given name if it exists in settings, else raises an error.
pub async fn create_provider(
settings: &SettingsManager,
provider: &str,
) -> Result<Arc<dyn AiProvider>>Initializes the provider with the given name if it exists in settings, else raises an error.