pub struct ChatActorBuilder { /* private fields */ }Implementations
Sourceimpl ChatActorBuilder
impl ChatActorBuilder
Sourcepub fn tycode(
workspace_roots: Vec<PathBuf>,
root_dir: Option<PathBuf>,
profile: Option<String>,
) -> Result<Self>
pub fn tycode( workspace_roots: Vec<PathBuf>, root_dir: Option<PathBuf>, profile: Option<String>, ) -> Result<Self>
Create a Tycode coding agent builder with all standard setup.
This handles:
- Setting root_dir to ~/.tycode if not provided
- Creating SettingsManager with the specified profile
- Creating SteeringDocuments with settings from that profile
- Creating MemoryLog
- Creating all context managers and prompt components
After this, callers only need to set optional overrides and call build().
pub fn new(workspace_roots: Vec<PathBuf>, root_dir: PathBuf) -> Self
pub fn profile(self, name: Option<String>) -> Self
pub fn provider(self, provider: Arc<dyn AiProvider>) -> Self
pub fn agent_name(self, name: String) -> Self
pub fn with_agent(self, agent: impl Agent + 'static) -> Self
pub fn with_tool(self, tool: impl ToolExecutor + 'static) -> Self
pub fn with_prompt_component( self, component: impl PromptComponent + 'static, ) -> Self
pub fn with_context_component( self, component: impl ContextComponent + 'static, ) -> Self
pub fn with_module(&mut self, module: Arc<dyn Module>)
pub fn build(self) -> Result<(ChatActor, UnboundedReceiver<ChatEvent>)>