Module commands

Module commands 

Structs

CommandInfo

Functions

get_available_commands
Get all available commands with their descriptions
handle_debug_ui_command
is_known_command
Check if the given input string starts with a known command
process_command
Process a command and directly mutate the actor state