pub async fn process_command(
state: &mut ActorState,
command: &str,
) -> Vec<ChatMessage>Expand description
Process a command and directly mutate the actor state
pub async fn process_command(
state: &mut ActorState,
command: &str,
) -> Vec<ChatMessage>Process a command and directly mutate the actor state