ChatEvent

Enum ChatEvent 

pub enum ChatEvent {
Show 18 variants MessageAdded(ChatMessage), StreamStart { message_id: String, agent: String, model: Model, }, StreamDelta { message_id: String, text: String, }, StreamReasoningDelta { message_id: String, text: String, }, StreamEnd { message: ChatMessage, }, Settings(Value), TypingStatusChanged(bool), ConversationCleared, ToolRequest(ToolRequest), ToolExecutionCompleted { tool_call_id: String, tool_name: String, tool_result: ToolExecutionResult, success: bool, error: Option<String>, }, OperationCancelled { message: String, }, RetryAttempt { attempt: u32, max_retries: u32, error: String, backoff_ms: u64, }, TaskUpdate(TaskList), SessionsList { sessions: Vec<SessionMetadata>, }, ProfilesList { profiles: Vec<String>, }, TimingUpdate { waiting_for_human: Duration, ai_processing: Duration, tool_execution: Duration, }, ModuleSchemas { schemas: Vec<ModuleSchemaInfo>, }, Error(String),
}
ChatEvent are the messages sent from the actor - the output of the actor.

The actor is built with 2 channels - an input and output channel. Requests are sent to the actor through the input channel. Requests may generate 1 or move ChatEvents in response which are sent to the output channel. Various applications (CLI/VSCode/Tests) process chat events to implement their application sepecific logic/rendering.

Variants



MessageAdded(ChatMessage)



StreamStart

Fields

message_id: String
agent: String
model: Model


StreamDelta

Fields

message_id: String
text: String


StreamReasoningDelta

Fields

message_id: String
text: String


StreamEnd

Fields

message: ChatMessage


Settings(Value)



TypingStatusChanged(bool)



ConversationCleared



ToolRequest(ToolRequest)



ToolExecutionCompleted

Fields

tool_call_id: String
tool_name: String
success: bool


OperationCancelled

Fields

message: String


RetryAttempt

Fields

attempt: u32
max_retries: u32
error: String
backoff_ms: u64


TaskUpdate(TaskList)



SessionsList

Fields



ProfilesList

Fields

profiles: Vec<String>


TimingUpdate

Fields

waiting_for_human: Duration
ai_processing: Duration
tool_execution: Duration


ModuleSchemas

Fields



Error(String)