Functions
- prepare_
request - Prepare an AI conversation request. This handles the work of fully assembling a request - including building the prompt (from the agent and prompt_builder), the context message (from the context_builder), selecting the correct model, etc.
- select_
model_ for_ agent - Select the appropriate model for an agent based on settings and cost constraints.