Module find

Module find 

Structs

MatchResult
The result of a “find in file” operation that finds the closest match to a given vec of lines in a test.

Functions

find_closest_match
Find the closest matching section in source lines for the given search lines