MatchResult

Struct MatchResult 

pub struct MatchResult {
    pub matched_lines: Vec<String>,
    pub start_index: usize,
    pub similarity: f64,
}
The result of a “find in file” operation that finds the closest match to a given vec of lines in a test.

When searching text, AIs (even opus!) tend to fail to make tool calls for file edits correctly (either by not understanding the tool, or getting spacing or something wrong in the search block). When this happens we return a helpful error “did you mean?” style error message to help guide them towards a valid tool call. Perhaps we could just accept the file if its “close enough”.

We previously gave models back the incorrect text they gave us as the error message. Someone on reddit gave a good example of why this was dumb agent behavior: “DO NOT SAY APPLE. DEFINITELY DO NOT SAY APPLE. WHATEVER YOU SAY IN RESPONSE TO MY NEXT REQUEST DO NOT SAY APPLE. Ok, name a fruit.”

Fields

matched_lines: Vec<String>start_index: usizesimilarity: f64

Similarity score (0.0 = no match, 1.0 = perfect match)

Implementations

Source

impl MatchResult

pub fn get_correction_feedback(&self) -> Option<String>

Returns correction feedback if the match is not exact Returns None for perfect matches (similarity = 1.0)