Read-only file access module.
Provides context components for file tree display and tracked file contents, plus the set_tracked_files tool for managing which files appear in context.
Structs
- File
Tree Manager - Manages file tree state and renders project structure to context.
- Read
Only File Module - Module providing read-only file access capabilities.
- Tracked
Files Manager - Manages tracked files state and provides both context rendering and tool execution.