pub struct Resolver { /* private fields */ }Expand description
Responsible for mapping to and from the virtual file system we present to AI agents where each workspace is in a root file system.
Implementations
Sourceimpl Resolver
impl Resolver
Sourcepub fn new(workspace_roots: Vec<PathBuf>) -> Result<Self>
pub fn new(workspace_roots: Vec<PathBuf>) -> Result<Self>
Create a new PathResolver with the given workspace roots. Non-existent directories are skipped with a warning (handles VSCode multi-workspace deletion).
Sourcepub fn resolve_path(&self, path_str: &str) -> Result<ResolvedPath>
pub fn resolve_path(&self, path_str: &str) -> Result<ResolvedPath>
Resolves a path in the virtual file system to the real path on disk
Sourcepub fn canonicalize(&self, path: &Path) -> Result<ResolvedPath>
pub fn canonicalize(&self, path: &Path) -> Result<ResolvedPath>
Converts a real on disk path to the virtual file system path
pub fn root(&self, workspace: &str) -> Option<PathBuf>
pub fn roots(&self) -> Vec<String>