PromptComponentSelection

Enum PromptComponentSelection 

pub enum PromptComponentSelection {
    All,
    Only(&'static [PromptComponentId]),
    Exclude(&'static [PromptComponentId]),
    None,
}
Selection strategy for which prompt components an agent wants included.

Prompt components contribute to the system prompt - the initial instructions given to the AI that shape its behavior. Examples include style mandates, autonomy level instructions, tool usage guidelines, etc.

Most agents want all components, but specialized agents (like memory manager) may want to exclude certain components (like autonomy instructions) because they have their own bespoke prompts.

Variants



All

Include all available prompt components



Only(&'static [PromptComponentId])

Include only the specified prompt components



Exclude(&'static [PromptComponentId])

Include all except the specified prompt components



None

Exclude all prompt components (agent has its own complete prompt)