SessionStateComponent

Trait SessionStateComponent 

pub trait SessionStateComponent: Send + Sync {
    // Required methods
    fn key(&self) -> &str;
    fn save(&self) -> Value;
    fn load(&self, state: Value) -> Result<()>;
}
Handles session persistence for a module’s state.

Modules that need to persist state across sessions should return an implementation of this trait from Module::session_state().

Required Methods

fn key(&self) -> &str

Unique key for storing this module’s state in session data.

fn save(&self) -> Value

Serialize current state for persistence.

fn load(&self, state: Value) -> Result<()>

Restore state from persisted session data.

Implementors