Module config

Module config 

Memory module configuration.

This file contains the configuration struct for the memory module. Module configuration should live with the module implementation, not in a centralized settings file.

Structs

MemoryConfig
Tycode allows models to store memories which persist between conversations. When enabled, Tycode will also send background requests to models specifically to extract memories from user input, otherwise models may choose to store memories, but generally do not. Memories are appended to a file (in ~/.tycode/memories/memories_log.json) and occasionally compacted in to a memory summary. Memories are injected to prompts so future conversations may benefit from the learnings.