Log-based memory system with JSON-backed storage.
Memories are stored as a JSON log at ~/.tycode/memory/memories_log.json. Each memory has a monotonic sequence number, content, timestamp, and optional source.
Log-based memory system with JSON-backed storage.
Memories are stored as a JSON log at ~/.tycode/memory/memories_log.json. Each memory has a monotonic sequence number, content, timestamp, and optional source.