Module prompt

Module prompt 

Prompt component for rendering memory compaction in the system prompt.

When a compaction exists, renders the compaction summary (compressed history).

Structs

CompactionPromptComponent
Renders memory compaction summary in the system prompt.

Constants

ID