Structs
Functions
- get_
available_ commands - Get all available commands with their descriptions
- handle_
debug_ ui_ command - is_
known_ command - Check if the given input string starts with a known command
- process_
command - Process a command and directly mutate the actor state