pub enum ChatEvent {
Show 18 variants
MessageAdded(ChatMessage),
StreamStart {
message_id: String,
agent: String,
model: Model,
},
StreamDelta {
message_id: String,
text: String,
},
StreamReasoningDelta {
message_id: String,
text: String,
},
StreamEnd {
message: ChatMessage,
},
Settings(Value),
TypingStatusChanged(bool),
ConversationCleared,
ToolRequest(ToolRequest),
ToolExecutionCompleted {
tool_call_id: String,
tool_name: String,
tool_result: ToolExecutionResult,
success: bool,
error: Option<String>,
},
OperationCancelled {
message: String,
},
RetryAttempt {
attempt: u32,
max_retries: u32,
error: String,
backoff_ms: u64,
},
TaskUpdate(TaskList),
SessionsList {
sessions: Vec<SessionMetadata>,
},
ProfilesList {
profiles: Vec<String>,
},
TimingUpdate {
waiting_for_human: Duration,
ai_processing: Duration,
tool_execution: Duration,
},
ModuleSchemas {
schemas: Vec<ModuleSchemaInfo>,
},
Error(String),
}Expand description
ChatEvent are the messages sent from the actor - the output of the actor.
The actor is built with 2 channels - an input and output channel. Requests
are sent to the actor through the input channel. Requests may generate 1 or
move ChatEvents in response which are sent to the output channel. Various
applications (CLI/VSCode/Tests) process chat events to implement their
application sepecific logic/rendering.
Variants
MessageAdded(ChatMessage)
StreamStart
StreamDelta
StreamReasoningDelta
StreamEnd
Fields

message: ChatMessageSettings(Value)
TypingStatusChanged(bool)
ConversationCleared
ToolRequest(ToolRequest)
ToolExecutionCompleted
Fields

tool_result: ToolExecutionResultOperationCancelled
RetryAttempt
TaskUpdate(TaskList)
SessionsList
Fields

sessions: Vec<SessionMetadata>ProfilesList
TimingUpdate
ModuleSchemas
Fields

schemas: Vec<ModuleSchemaInfo>Error(String)