pub struct MemoryConfig {
pub enabled: bool,
pub recorder_cost: ModelCost,
pub context_message_count: usize,
pub summarizer_cost: ModelCost,
pub recent_memories_count: usize,
pub auto_compaction_threshold: Option<usize>,
}Expand description
Tycode allows models to store memories which persist between conversations. When enabled, Tycode will also send background requests to models specifically to extract memories from user input, otherwise models may choose to store memories, but generally do not. Memories are appended to a file (in ~/.tycode/memories/memories_log.json) and occasionally compacted in to a memory summary. Memories are injected to prompts so future conversations may benefit from the learnings.
Fields
enabled: boolEnable or Disable background calls to extract memories from conversation context.
recorder_cost: ModelCostCost control for the background model that is used to record memories.
context_message_count: usizeNumber of recent messages send to the background model; more messages will improve context for the background model, however will increase costs.
summarizer_cost: ModelCostCost control for the model that is used to compact memories.
recent_memories_count: usizeNumber of recent memories to include in the agent’s context
auto_compaction_threshold: Option<usize>When set, automatically trigger background compaction after this many new memories since the last compaction.
Implementations