Structs
- Settings
Manager - Various settings used throughout Tycode. Each process has its own local settings that the user may update without impacting any other session (for example increase the maximum model cost for 1 session). Settings can also be saved and when saved, future processes will use the same settings.