Structs
- File
Modification - File modification details
- Tool
Request - Request passed to tool execution
Enums
- Continuation
Preference - Preference for whether the conversation should continue after tool execution
- File
Operation - File modification operation type
- Tool
Category - Tool category that determines the type of operation
- Tool
Output - Output from tool execution - either a direct result or an action for the orchestrator
Traits
- Tool
Call Handle - Handle for a validated tool call, encapsulating request generation and execution
- Tool
Executor